==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/pl.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'pl', {
	acccessKey: 'Klawisz dostępu',
	advanced: 'Zaawansowane',
	advisoryContentType: 'Typ MIME obiektu docelowego',
	advisoryTitle: 'Opis obiektu docelowego',
	anchor: {
		toolbar: 'Wstaw/edytuj kotwicę',
		menu: 'Właściwości kotwicy',
		title: 'Właściwości kotwicy',
		name: 'Nazwa kotwicy',
		errorName: 'Wpisz nazwę kotwicy',
		remove: 'Usuń kotwicę'
	},
	anchorId: 'Wg identyfikatora',
	anchorName: 'Wg nazwy',
	charset: 'Kodowanie znaków obiektu docelowego',
	cssClasses: 'Nazwa klasy CSS',
	emailAddress: 'Adres e-mail',
	emailBody: 'Treść',
	emailSubject: 'Temat',
	id: 'Id',
	info: 'Informacje ',
	langCode: 'Kod języka',
	langDir: 'Kierunek tekstu',
	langDirLTR: 'Od lewej do prawej (LTR)',
	langDirRTL: 'Od prawej do lewej (RTL)',
	menu: 'Edytuj odnośnik',
	name: 'Nazwa',
	noAnchors: '(W dokumencie nie zdefiniowano żadnych kotwic)',
	noEmail: 'Podaj adres e-mail',
	noUrl: 'Podaj adres URL',
	other: '<inny>',
	popupDependent: 'Okno zależne (Netscape)',
	popupFeatures: 'Właściwości wyskakującego okna',
	popupFullScreen: 'Pełny ekran (IE)',
	popupLeft: 'Pozycja w poziomie',
	popupLocationBar: 'Pasek adresu',
	popupMenuBar: 'Pasek menu',
	popupResizable: 'Skalowalny',
	popupScrollBars: 'Paski przewijania',
	popupStatusBar: 'Pasek statusu',
	popupToolbar: 'Pasek narzędzi',
	popupTop: 'Pozycja w pionie',
	rel: 'Relacja',
	selectAnchor: 'Wybierz kotwicę',
	styles: 'Styl',
	tabIndex: 'Indeks kolejności',
	target: 'Obiekt docelowy',
	targetFrame: '<ramka>',
	targetFrameName: 'Nazwa ramki docelowej',
	targetPopup: '<wyskakujące okno>',
	targetPopupName: 'Nazwa wyskakującego okna',
	title: 'Odnośnik',
	toAnchor: 'Odnośnik wewnątrz strony (kotwica)',
	toEmail: 'Adres e-mail',
	toUrl: 'Adres URL',
	toolbar: 'Wstaw/edytuj odnośnik',
	type: 'Typ odnośnika',
	unlink: 'Usuń odnośnik',
	upload: 'Wyślij'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/pl.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'pl', {
	acccessKey: 'Klawisz dostępu',
	advanced: 'Zaawansowane',
	advisoryContentType: 'Typ MIME obiektu docelowego',
	advisoryTitle: 'Opis obiektu docelowego',
	anchor: {
		toolbar: 'Wstaw/edytuj kotwicę',
		menu: 'Właściwości kotwicy',
		title: 'Właściwości kotwicy',
		name: 'Nazwa kotwicy',
		errorName: 'Wpisz nazwę kotwicy',
		remove: 'Usuń kotwicę'
	},
	anchorId: 'Wg identyfikatora',
	anchorName: 'Wg nazwy',
	charset: 'Kodowanie znaków obiektu docelowego',
	cssClasses: 'Nazwa klasy CSS',
	download: 'Wymuś pobieranie',
	displayText: 'Wyświetlany tekst',
	emailAddress: 'Adres e-mail',
	emailBody: 'Treść',
	emailSubject: 'Temat',
	id: 'Id',
	info: 'Informacje ',
	langCode: 'Kod języka',
	langDir: 'Kierunek tekstu',
	langDirLTR: 'Od lewej do prawej (LTR)',
	langDirRTL: 'Od prawej do lewej (RTL)',
	menu: 'Edytuj odnośnik',
	name: 'Nazwa',
	noAnchors: '(W dokumencie nie zdefiniowano żadnych kotwic)',
	noEmail: 'Podaj adres e-mail',
	noUrl: 'Podaj adres URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<inny>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Okno zależne (Netscape)',
	popupFeatures: 'Właściwości wyskakującego okna',
	popupFullScreen: 'Pełny ekran (IE)',
	popupLeft: 'Pozycja w poziomie',
	popupLocationBar: 'Pasek adresu',
	popupMenuBar: 'Pasek menu',
	popupResizable: 'Skalowalny',
	popupScrollBars: 'Paski przewijania',
	popupStatusBar: 'Pasek statusu',
	popupToolbar: 'Pasek narzędzi',
	popupTop: 'Pozycja w pionie',
	rel: 'Relacja',
	selectAnchor: 'Wybierz kotwicę',
	styles: 'Styl',
	tabIndex: 'Indeks kolejności',
	target: 'Obiekt docelowy',
	targetFrame: '<ramka>',
	targetFrameName: 'Nazwa ramki docelowej',
	targetPopup: '<wyskakujące okno>',
	targetPopupName: 'Nazwa wyskakującego okna',
	title: 'Odnośnik',
	toAnchor: 'Odnośnik wewnątrz strony (kotwica)',
	toEmail: 'Adres e-mail',
	toUrl: 'Adres URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Wstaw/edytuj odnośnik',
	type: 'Typ odnośnika',
	unlink: 'Usuń odnośnik',
	upload: 'Wyślij'
} );
